from __future__ import annotations

from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum

from xsdata.models.datatype import XmlDate, XmlDateTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03"


@dataclass(kw_only=True)
class AccountSchemeName1Choice:
    cd: None | str = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: None | str = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class ActiveCurrencyAndAmount:
    value: Decimal = field(
        metadata={
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        }
    )
    ccy: str = field(
        metadata={
            "name": "Ccy",
            "type": "Attribute",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        }
    )


@dataclass(kw_only=True)
class ActiveOrHistoricCurrencyAnd13DecimalAmount:
    value: Decimal = field(
        metadata={
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 13,
        }
    )
    ccy: str = field(
        metadata={
            "name": "Ccy",
            "type": "Attribute",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        }
    )


class AddressType2Code(Enum):
    ADDR = "ADDR"
    PBOX = "PBOX"
    HOME = "HOME"
    BIZZ = "BIZZ"
    MLTO = "MLTO"
    DLVY = "DLVY"


class AgreementFramework1Code(Enum):
    FBAA = "FBAA"
    BBAA = "BBAA"
    DERV = "DERV"
    ISDA = "ISDA"
    NONR = "NONR"


class CollateralAccountType1Code(Enum):
    HOUS = "HOUS"
    CLIE = "CLIE"
    LIPR = "LIPR"
    MGIN = "MGIN"
    DFLT = "DFLT"


class CollateralSubstitutionSequence1Code(Enum):
    INIT = "INIT"
    UPDD = "UPDD"


class CollateralSubstitutionType1Code(Enum):
    AVMG = "AVMG"
    ASIA = "ASIA"


@dataclass(kw_only=True)
class DateAndDateTimeChoice:
    dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "Dt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    dt_tm: None | XmlDateTime = field(
        default=None,
        metadata={
            "name": "DtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


class DateType2Code(Enum):
    OPEN = "OPEN"


class DepositType1Code(Enum):
    FITE = "FITE"
    CALL = "CALL"


class ExposureType5Code(Enum):
    BFWD = "BFWD"
    PAYM = "PAYM"
    CCPC = "CCPC"
    COMM = "COMM"
    CRDS = "CRDS"
    CRTL = "CRTL"
    CRSP = "CRSP"
    CCIR = "CCIR"
    CRPR = "CRPR"
    EQUI = "EQUI"
    EQPT = "EQPT"
    EQUS = "EQUS"
    EXTD = "EXTD"
    EXPT = "EXPT"
    FIXI = "FIXI"
    FORX = "FORX"
    FORW = "FORW"
    FUTR = "FUTR"
    OPTN = "OPTN"
    LIQU = "LIQU"
    OTCD = "OTCD"
    REPO = "REPO"
    RVPO = "RVPO"
    SLOA = "SLOA"
    SBSC = "SBSC"
    SCRP = "SCRP"
    SLEB = "SLEB"
    SHSL = "SHSL"
    SCIR = "SCIR"
    SCIE = "SCIE"
    SWPT = "SWPT"
    TBAS = "TBAS"
    TRBD = "TRBD"
    TRCP = "TRCP"


@dataclass(kw_only=True)
class FinancialInstrumentQuantity1Choice:
    unit: None | Decimal = field(
        default=None,
        metadata={
            "name": "Unit",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 18,
            "fraction_digits": 17,
        },
    )
    face_amt: None | Decimal = field(
        default=None,
        metadata={
            "name": "FaceAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        },
    )
    amtsd_val: None | Decimal = field(
        default=None,
        metadata={
            "name": "AmtsdVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        },
    )


@dataclass(kw_only=True)
class GenericIdentification29:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    issr: str = field(
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class GenericIdentification30:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "pattern": r"[a-zA-Z0-9]{4}",
        }
    )
    issr: str = field(
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class GenericIdentification40:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "pattern": r"[a-zA-Z0-9]{4}",
        }
    )
    issr: str = field(
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class IdentificationSource3Choice:
    cd: None | str = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: None | str = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


class NamePrefix1Code(Enum):
    DOCT = "DOCT"
    MIST = "MIST"
    MISS = "MISS"
    MADM = "MADM"


@dataclass(kw_only=True)
class PartyTextInformation1:
    dclrtn_dtls: None | str = field(
        default=None,
        metadata={
            "name": "DclrtnDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 350,
        },
    )
    pty_ctct_dtls: None | str = field(
        default=None,
        metadata={
            "name": "PtyCtctDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 140,
        },
    )
    regn_dtls: None | str = field(
        default=None,
        metadata={
            "name": "RegnDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 350,
        },
    )


@dataclass(kw_only=True)
class PostalAddress2:
    strt_nm: None | str = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 70,
        },
    )
    pst_cd_id: str = field(
        metadata={
            "name": "PstCdId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 16,
        }
    )
    twn_nm: str = field(
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    ctry_sub_dvsn: None | str = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: str = field(
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        }
    )


class PriceValueType1Code(Enum):
    DISC = "DISC"
    PREM = "PREM"
    PARV = "PARV"


@dataclass(kw_only=True)
class Reference17:
    coll_sbstitn_req_id: str = field(
        metadata={
            "name": "CollSbstitnReqId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    coll_sbstitn_rspn_id: None | str = field(
        default=None,
        metadata={
            "name": "CollSbstitnRspnId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


class SafekeepingPlace1Code(Enum):
    CUST = "CUST"
    ICSD = "ICSD"
    NCSD = "NCSD"
    SHHE = "SHHE"


class SafekeepingPlace3Code(Enum):
    SHHE = "SHHE"


@dataclass(kw_only=True)
class SimpleIdentificationInformation4:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )


@dataclass(kw_only=True)
class SupplementaryDataEnvelope1:
    any_element: None | object = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


class TypeOfIdentification2Code(Enum):
    ARNU = "ARNU"
    CHTY = "CHTY"
    CORP = "CORP"
    FIIN = "FIIN"
    TXID = "TXID"


@dataclass(kw_only=True)
class AccountIdentification26:
    prtry: SimpleIdentificationInformation4 = field(
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class AgreementFramework1Choice:
    agrmt_frmwk: None | AgreementFramework1Code = field(
        default=None,
        metadata={
            "name": "AgrmtFrmwk",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    prtry_id: None | GenericIdentification30 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class CollateralAccountIdentificationType1Choice:
    tp: None | CollateralAccountType1Code = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    prtry: None | GenericIdentification29 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class ContactIdentification2:
    nm_prfx: None | NamePrefix1Code = field(
        default=None,
        metadata={
            "name": "NmPrfx",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    gvn_nm: None | str = field(
        default=None,
        metadata={
            "name": "GvnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    nm: str = field(
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    phne_nb: None | str = field(
        default=None,
        metadata={
            "name": "PhneNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    mob_nb: None | str = field(
        default=None,
        metadata={
            "name": "MobNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    fax_nb: None | str = field(
        default=None,
        metadata={
            "name": "FaxNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    email_adr: None | str = field(
        default=None,
        metadata={
            "name": "EmailAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 256,
        },
    )


@dataclass(kw_only=True)
class DateCode9Choice:
    cd: None | DateType2Code = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    prtry: None | GenericIdentification30 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class GenericAccountIdentification1:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 34,
        }
    )
    schme_nm: None | AccountSchemeName1Choice = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    issr: None | str = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class GenericIdentification58:
    id: None | str = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    tp: GenericIdentification40 = field(
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class IdentificationType40Choice:
    cd: None | TypeOfIdentification2Code = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    prtry: None | GenericIdentification29 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class NameAndAddress6:
    nm: str = field(
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 70,
        }
    )
    adr: PostalAddress2 = field(
        metadata={
            "name": "Adr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class OtherIdentification1:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    sfx: None | str = field(
        default=None,
        metadata={
            "name": "Sfx",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 16,
        },
    )
    tp: IdentificationSource3Choice = field(
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class OtherTypeOfCollateral2:
    desc: str = field(
        metadata={
            "name": "Desc",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 140,
        }
    )
    qty: None | FinancialInstrumentQuantity1Choice = field(
        default=None,
        metadata={
            "name": "Qty",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class PostalAddress1:
    adr_tp: None | AddressType2Code = field(
        default=None,
        metadata={
            "name": "AdrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    adr_line: list[str] = field(
        default_factory=list,
        metadata={
            "name": "AdrLine",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "max_occurs": 5,
            "min_length": 1,
            "max_length": 70,
        },
    )
    strt_nm: None | str = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 70,
        },
    )
    bldg_nb: None | str = field(
        default=None,
        metadata={
            "name": "BldgNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 16,
        },
    )
    pst_cd: None | str = field(
        default=None,
        metadata={
            "name": "PstCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 16,
        },
    )
    twn_nm: None | str = field(
        default=None,
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry_sub_dvsn: None | str = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: str = field(
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        }
    )


@dataclass(kw_only=True)
class PostalAddress8:
    adr_tp: None | AddressType2Code = field(
        default=None,
        metadata={
            "name": "AdrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    adr_line: list[str] = field(
        default_factory=list,
        metadata={
            "name": "AdrLine",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "max_occurs": 5,
            "min_length": 1,
            "max_length": 70,
        },
    )
    strt_nm: None | str = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 70,
        },
    )
    bldg_nb: None | str = field(
        default=None,
        metadata={
            "name": "BldgNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 16,
        },
    )
    pst_cd: None | str = field(
        default=None,
        metadata={
            "name": "PstCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 16,
        },
    )
    twn_nm: None | str = field(
        default=None,
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry_sub_dvsn: None | str = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: str = field(
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        }
    )


@dataclass(kw_only=True)
class PriceRateOrAmountChoice:
    rate: None | Decimal = field(
        default=None,
        metadata={
            "name": "Rate",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    amt: None | ActiveOrHistoricCurrencyAnd13DecimalAmount = field(
        default=None,
        metadata={
            "name": "Amt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class SafekeepingPlaceTypeAndAnyBicidentifier1:
    class Meta:
        name = "SafekeepingPlaceTypeAndAnyBICIdentifier1"

    sfkpg_plc_tp: SafekeepingPlace1Code = field(
        metadata={
            "name": "SfkpgPlcTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        }
    )


@dataclass(kw_only=True)
class SafekeepingPlaceTypeAndText1:
    sfkpg_plc_tp: SafekeepingPlace3Code = field(
        metadata={
            "name": "SfkpgPlcTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    id: None | str = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class SecuritiesAccount19:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    tp: None | GenericIdentification30 = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass(kw_only=True)
class SupplementaryData1:
    plc_and_nm: None | str = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: SupplementaryDataEnvelope1 = field(
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class YieldedOrValueType1Choice:
    yldd: None | bool = field(
        default=None,
        metadata={
            "name": "Yldd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    val_tp: None | PriceValueType1Code = field(
        default=None,
        metadata={
            "name": "ValTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class AccountIdentification4Choice:
    iban: None | str = field(
        default=None,
        metadata={
            "name": "IBAN",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"[A-Z]{2,2}[0-9]{2,2}[a-zA-Z0-9]{1,30}",
        },
    )
    othr: None | GenericAccountIdentification1 = field(
        default=None,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class Agreement2:
    agrmt_dtls: str = field(
        metadata={
            "name": "AgrmtDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 140,
        }
    )
    agrmt_id: None | str = field(
        default=None,
        metadata={
            "name": "AgrmtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 140,
        },
    )
    agrmt_dt: XmlDate = field(
        metadata={
            "name": "AgrmtDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    base_ccy: str = field(
        metadata={
            "name": "BaseCcy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        }
    )
    agrmt_frmwk: None | AgreementFramework1Choice = field(
        default=None,
        metadata={
            "name": "AgrmtFrmwk",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class AlternatePartyIdentification5:
    id_tp: IdentificationType40Choice = field(
        metadata={
            "name": "IdTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    ctry: str = field(
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        }
    )
    altrn_id: str = field(
        metadata={
            "name": "AltrnId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )


@dataclass(kw_only=True)
class CollateralAccount1:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    tp: None | CollateralAccountIdentificationType1Choice = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass(kw_only=True)
class DateFormat14Choice:
    dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "Dt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    dt_cd: None | DateCode9Choice = field(
        default=None,
        metadata={
            "name": "DtCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class NameAndAddress13:
    nm: str = field(
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 350,
        }
    )
    adr: None | PostalAddress8 = field(
        default=None,
        metadata={
            "name": "Adr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class NameAndAddress5:
    nm: str = field(
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 350,
        }
    )
    adr: None | PostalAddress1 = field(
        default=None,
        metadata={
            "name": "Adr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class PartyIdentification33Choice:
    any_bic: None | str = field(
        default=None,
        metadata={
            "name": "AnyBIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    prtry_id: None | GenericIdentification29 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    nm_and_adr: None | NameAndAddress6 = field(
        default=None,
        metadata={
            "name": "NmAndAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class Price2:
    tp: YieldedOrValueType1Choice = field(
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    val: PriceRateOrAmountChoice = field(
        metadata={
            "name": "Val",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class SafekeepingPlaceFormat7Choice:
    id: None | SafekeepingPlaceTypeAndText1 = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    ctry: None | str = field(
        default=None,
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"[A-Z]{2,2}",
        },
    )
    tp_and_id: None | SafekeepingPlaceTypeAndAnyBicidentifier1 = field(
        default=None,
        metadata={
            "name": "TpAndId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    prtry: None | GenericIdentification58 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class SecurityIdentification14:
    isin: None | str = field(
        default=None,
        metadata={
            "name": "ISIN",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"[A-Z0-9]{12,12}",
        },
    )
    othr_id: list[OtherIdentification1] = field(
        default_factory=list,
        metadata={
            "name": "OthrId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    desc: None | str = field(
        default=None,
        metadata={
            "name": "Desc",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 140,
        },
    )


@dataclass(kw_only=True)
class SubAccount4:
    id: AccountIdentification26 = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    chrtc: None | str = field(
        default=None,
        metadata={
            "name": "Chrtc",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class CashCollateral3:
    coll_id: None | str = field(
        default=None,
        metadata={
            "name": "CollId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    csh_acct_id: None | AccountIdentification4Choice = field(
        default=None,
        metadata={
            "name": "CshAcctId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    dpst_amt: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "DpstAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    dpst_tp: None | DepositType1Code = field(
        default=None,
        metadata={
            "name": "DpstTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    mtrty_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "MtrtyDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    val_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "ValDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    xchg_rate: None | Decimal = field(
        default=None,
        metadata={
            "name": "XchgRate",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    coll_val: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "CollVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    hrcut: None | Decimal = field(
        default=None,
        metadata={
            "name": "Hrcut",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )


@dataclass(kw_only=True)
class CashCollateral5:
    coll_id: None | str = field(
        default=None,
        metadata={
            "name": "CollId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    csh_acct_id: None | AccountIdentification4Choice = field(
        default=None,
        metadata={
            "name": "CshAcctId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    asst_nb: None | str = field(
        default=None,
        metadata={
            "name": "AsstNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    dpst_amt: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "DpstAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    dpst_tp: None | DepositType1Code = field(
        default=None,
        metadata={
            "name": "DpstTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    mtrty_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "MtrtyDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    val_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "ValDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    xchg_rate: None | Decimal = field(
        default=None,
        metadata={
            "name": "XchgRate",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    coll_val: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "CollVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    hrcut: None | Decimal = field(
        default=None,
        metadata={
            "name": "Hrcut",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )


@dataclass(kw_only=True)
class CollateralOwnership1:
    prtry: bool = field(
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    clnt_nm: None | PartyIdentification33Choice = field(
        default=None,
        metadata={
            "name": "ClntNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class Obligation3:
    pty_a: PartyIdentification33Choice = field(
        metadata={
            "name": "PtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    svcg_pty_a: None | PartyIdentification33Choice = field(
        default=None,
        metadata={
            "name": "SvcgPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    pty_b: PartyIdentification33Choice = field(
        metadata={
            "name": "PtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    svcg_pty_b: None | PartyIdentification33Choice = field(
        default=None,
        metadata={
            "name": "SvcgPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    coll_acct_id: None | CollateralAccount1 = field(
        default=None,
        metadata={
            "name": "CollAcctId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    xpsr_tp: None | ExposureType5Code = field(
        default=None,
        metadata={
            "name": "XpsrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    valtn_dt: DateAndDateTimeChoice = field(
        metadata={
            "name": "ValtnDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class OtherCollateral2:
    coll_id: None | str = field(
        default=None,
        metadata={
            "name": "CollId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    lttr_of_cdt_id: None | str = field(
        default=None,
        metadata={
            "name": "LttrOfCdtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    lttr_of_cdt_amt: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "LttrOfCdtAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    grnt_amt: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "GrntAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    othr_tp_of_coll: None | OtherTypeOfCollateral2 = field(
        default=None,
        metadata={
            "name": "OthrTpOfColl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    isse_dt: None | DateFormat14Choice = field(
        default=None,
        metadata={
            "name": "IsseDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    xpry_dt: None | DateFormat14Choice = field(
        default=None,
        metadata={
            "name": "XpryDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    ltd_cvrg_ind: None | bool = field(
        default=None,
        metadata={
            "name": "LtdCvrgInd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    issr: None | PartyIdentification33Choice = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    val_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "ValDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    xchg_rate: None | Decimal = field(
        default=None,
        metadata={
            "name": "XchgRate",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    mkt_val: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "MktVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    hrcut: None | Decimal = field(
        default=None,
        metadata={
            "name": "Hrcut",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    coll_val: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "CollVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    sfkpg_plc: None | SafekeepingPlaceFormat7Choice = field(
        default=None,
        metadata={
            "name": "SfkpgPlc",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    sfkpg_acct: None | SecuritiesAccount19 = field(
        default=None,
        metadata={
            "name": "SfkpgAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class OtherCollateral4:
    coll_id: None | str = field(
        default=None,
        metadata={
            "name": "CollId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    asst_nb: None | str = field(
        default=None,
        metadata={
            "name": "AsstNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    lttr_of_cdt_id: None | str = field(
        default=None,
        metadata={
            "name": "LttrOfCdtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    lttr_of_cdt_amt: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "LttrOfCdtAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    grnt_amt: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "GrntAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    othr_tp_of_coll: None | OtherTypeOfCollateral2 = field(
        default=None,
        metadata={
            "name": "OthrTpOfColl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    isse_dt: None | DateFormat14Choice = field(
        default=None,
        metadata={
            "name": "IsseDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    xpry_dt: None | DateFormat14Choice = field(
        default=None,
        metadata={
            "name": "XpryDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    ltd_cvrg_ind: None | bool = field(
        default=None,
        metadata={
            "name": "LtdCvrgInd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    issr: None | PartyIdentification33Choice = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    val_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "ValDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    xchg_rate: None | Decimal = field(
        default=None,
        metadata={
            "name": "XchgRate",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    mkt_val: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "MktVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    hrcut: None | Decimal = field(
        default=None,
        metadata={
            "name": "Hrcut",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    coll_val: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "CollVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    sfkpg_plc: None | SafekeepingPlaceFormat7Choice = field(
        default=None,
        metadata={
            "name": "SfkpgPlc",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    sfkpg_acct: None | SecuritiesAccount19 = field(
        default=None,
        metadata={
            "name": "SfkpgAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class PartyIdentification32Choice:
    bic: None | str = field(
        default=None,
        metadata={
            "name": "BIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    prtry_id: None | GenericIdentification29 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    nm_and_adr: None | NameAndAddress13 = field(
        default=None,
        metadata={
            "name": "NmAndAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class PartyIdentification34Choice:
    bic: None | str = field(
        default=None,
        metadata={
            "name": "BIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    nm_and_adr: None | NameAndAddress5 = field(
        default=None,
        metadata={
            "name": "NmAndAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    ctry: None | str = field(
        default=None,
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "pattern": r"[A-Z]{2,2}",
        },
    )


@dataclass(kw_only=True)
class PartyIdentificationAndAccount102:
    pty_id: PartyIdentification33Choice = field(
        metadata={
            "name": "PtyId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    acct_id: None | str = field(
        default=None,
        metadata={
            "name": "AcctId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    prcg_id: None | str = field(
        default=None,
        metadata={
            "name": "PrcgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    prcg_dt: None | DateAndDateTimeChoice = field(
        default=None,
        metadata={
            "name": "PrcgDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    sub_acct: None | SubAccount4 = field(
        default=None,
        metadata={
            "name": "SubAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    ctct_prsn: None | ContactIdentification2 = field(
        default=None,
        metadata={
            "name": "CtctPrsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class PartyIdentificationAndAccount77:
    id: PartyIdentification32Choice = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    altrn_id: None | AlternatePartyIdentification5 = field(
        default=None,
        metadata={
            "name": "AltrnId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    sfkpg_acct: None | str = field(
        default=None,
        metadata={
            "name": "SfkpgAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    prcg_id: None | str = field(
        default=None,
        metadata={
            "name": "PrcgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    addtl_inf: None | PartyTextInformation1 = field(
        default=None,
        metadata={
            "name": "AddtlInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class DeliveringPartiesAndAccount10:
    dpstry: PartyIdentification34Choice = field(
        metadata={
            "name": "Dpstry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    pty1: PartyIdentificationAndAccount102 = field(
        metadata={
            "name": "Pty1",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    pty2: None | PartyIdentificationAndAccount77 = field(
        default=None,
        metadata={
            "name": "Pty2",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class ReceivingPartiesAndAccount10:
    dpstry: PartyIdentification34Choice = field(
        metadata={
            "name": "Dpstry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    pty1: PartyIdentificationAndAccount102 = field(
        metadata={
            "name": "Pty1",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    pty2: None | PartyIdentificationAndAccount77 = field(
        default=None,
        metadata={
            "name": "Pty2",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class SettlementParties3Choice:
    dlvrg_sttlm_pties: None | DeliveringPartiesAndAccount10 = field(
        default=None,
        metadata={
            "name": "DlvrgSttlmPties",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    rcvg_sttlm_pties: None | ReceivingPartiesAndAccount10 = field(
        default=None,
        metadata={
            "name": "RcvgSttlmPties",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class SettlementDetails88:
    trad_dt: XmlDateTime = field(
        metadata={
            "name": "TradDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    sttlm_pties: None | SettlementParties3Choice = field(
        default=None,
        metadata={
            "name": "SttlmPties",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    coll_ownrsh: CollateralOwnership1 = field(
        metadata={
            "name": "CollOwnrsh",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class SecuritiesCollateral3:
    coll_id: None | str = field(
        default=None,
        metadata={
            "name": "CollId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    scty_id: SecurityIdentification14 = field(
        metadata={
            "name": "SctyId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    mtrty_dt: None | DateAndDateTimeChoice = field(
        default=None,
        metadata={
            "name": "MtrtyDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    ltd_cvrg_ind: None | bool = field(
        default=None,
        metadata={
            "name": "LtdCvrgInd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    qty: FinancialInstrumentQuantity1Choice = field(
        metadata={
            "name": "Qty",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    pric: None | Price2 = field(
        default=None,
        metadata={
            "name": "Pric",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    mkt_val: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "MktVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    hrcut: None | Decimal = field(
        default=None,
        metadata={
            "name": "Hrcut",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    coll_val: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "CollVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    val_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "ValDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    sfkpg_acct: None | SecuritiesAccount19 = field(
        default=None,
        metadata={
            "name": "SfkpgAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    sfkpg_plc: SafekeepingPlaceFormat7Choice = field(
        metadata={
            "name": "SfkpgPlc",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    sttlm_params: None | SettlementDetails88 = field(
        default=None,
        metadata={
            "name": "SttlmParams",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class SecuritiesCollateral4:
    coll_id: None | str = field(
        default=None,
        metadata={
            "name": "CollId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    asst_nb: None | str = field(
        default=None,
        metadata={
            "name": "AsstNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    scty_id: SecurityIdentification14 = field(
        metadata={
            "name": "SctyId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    mtrty_dt: None | DateAndDateTimeChoice = field(
        default=None,
        metadata={
            "name": "MtrtyDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    ltd_cvrg_ind: None | bool = field(
        default=None,
        metadata={
            "name": "LtdCvrgInd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    qty: FinancialInstrumentQuantity1Choice = field(
        metadata={
            "name": "Qty",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    pric: None | Price2 = field(
        default=None,
        metadata={
            "name": "Pric",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    mkt_val: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "MktVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    hrcut: None | Decimal = field(
        default=None,
        metadata={
            "name": "Hrcut",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    coll_val: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "CollVal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    val_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "ValDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    sfkpg_acct: None | SecuritiesAccount19 = field(
        default=None,
        metadata={
            "name": "SfkpgAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    sfkpg_plc: SafekeepingPlaceFormat7Choice = field(
        metadata={
            "name": "SfkpgPlc",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    sttlm_params: None | SettlementDetails88 = field(
        default=None,
        metadata={
            "name": "SttlmParams",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class CollateralSubstitution2:
    coll_sbstitn_seq: CollateralSubstitutionSequence1Code = field(
        metadata={
            "name": "CollSbstitnSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    sbstitn_rqrmnt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "SbstitnRqrmnt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    coll_sbstitn_tp: CollateralSubstitutionType1Code = field(
        metadata={
            "name": "CollSbstitnTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    std_sttlm_instrs: None | str = field(
        default=None,
        metadata={
            "name": "StdSttlmInstrs",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 140,
        },
    )
    scties_coll: list[SecuritiesCollateral4] = field(
        default_factory=list,
        metadata={
            "name": "SctiesColl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    csh_coll: list[CashCollateral5] = field(
        default_factory=list,
        metadata={
            "name": "CshColl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    othr_coll: list[OtherCollateral4] = field(
        default_factory=list,
        metadata={
            "name": "OthrColl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    lkd_refs: None | Reference17 = field(
        default=None,
        metadata={
            "name": "LkdRefs",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class CollateralSubstitution3:
    coll_sbstitn_seq: CollateralSubstitutionSequence1Code = field(
        metadata={
            "name": "CollSbstitnSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    sbstitn_rqrmnt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "SbstitnRqrmnt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    coll_sbstitn_tp: CollateralSubstitutionType1Code = field(
        metadata={
            "name": "CollSbstitnTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    std_sttlm_instrs: None | str = field(
        default=None,
        metadata={
            "name": "StdSttlmInstrs",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "min_length": 1,
            "max_length": 140,
        },
    )
    scties_coll: list[SecuritiesCollateral3] = field(
        default_factory=list,
        metadata={
            "name": "SctiesColl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    csh_coll: list[CashCollateral3] = field(
        default_factory=list,
        metadata={
            "name": "CshColl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    othr_coll: list[OtherCollateral2] = field(
        default_factory=list,
        metadata={
            "name": "OthrColl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    lkd_refs: None | Reference17 = field(
        default=None,
        metadata={
            "name": "LkdRefs",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class CollateralSubstitutionRequestV03:
    tx_id: str = field(
        metadata={
            "name": "TxId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    oblgtn: Obligation3 = field(
        metadata={
            "name": "Oblgtn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    agrmt: None | Agreement2 = field(
        default=None,
        metadata={
            "name": "Agrmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    coll_sbstitn_rtr: CollateralSubstitution2 = field(
        metadata={
            "name": "CollSbstitnRtr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
            "required": True,
        }
    )
    coll_sbstitn_dlvr: None | CollateralSubstitution3 = field(
        default=None,
        metadata={
            "name": "CollSbstitnDlvr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )
    splmtry_data: list[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03",
        },
    )


@dataclass(kw_only=True)
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:colr.010.001.03"

    coll_sbstitn_req: CollateralSubstitutionRequestV03 = field(
        metadata={
            "name": "CollSbstitnReq",
            "type": "Element",
            "required": True,
        }
    )



from pyiso20022.colr.colr_016_001_05.colr_016_001_05 import (
    ActiveCurrencyAndAmount,
    ActiveOrHistoricCurrencyAnd13DecimalAmount,
    Agreement4,
    AgreementFramework1Choice,
    AgreementFramework1Code,
    BlockChainAddressWallet3,
    BlockChainAddressWallet5,
    CashCollateral4,
    CcpmemberType1Code,
    Collateral53,
    CollateralAccount3,
    CollateralAccountIdentificationType3Choice,
    CollateralAccountType1Code,
    CollateralAmount1,
    CollateralAndExposureReportV05,
    CollateralAppliedExcess1Code,
    CollateralDirection1Code,
    CollateralOwnership3,
    CollateralType8Code,
    CollateralValuation13,
    DateAndDateTime2Choice,
    DateCode9Choice,
    DateFormat14Choice,
    DateType2Code,
    DepositType1Code,
    Document,
    EventFrequency6Code,
    ExposureType11Code,
    ExposureType13Code,
    FinancialInstrumentQuantity33Choice,
    GenericIdentification30,
    GenericIdentification36,
    GenericIdentification78,
    IdentificationSource3Choice,
    InterestComputationMethod2Code,
    NameAndAddress6,
    Obligation11,
    OtherCollateral10,
    OtherIdentification1,
    OtherTypeOfCollateral3,
    Pagination1,
    PartyIdentification178Choice,
    PartyIdentification242,
    PostalAddress2,
    Price7,
    PriceRateOrAmount3Choice,
    PriceValueType1Code,
    ReportParameters6,
    ReturnExcessCash1,
    ReturnExcessCash1Choice,
    ReturnExcessCash1Code,
    SafekeepingPlace1Code,
    SafekeepingPlace3Code,
    SafekeepingPlaceFormat29Choice,
    SafekeepingPlaceTypeAndIdentification1,
    SafekeepingPlaceTypeAndText8,
    SecuritiesAccount19,
    SecuritiesCollateral13,
    SecurityIdentification19,
    SettlementStatus3Code,
    ShortLong1Code,
    Summary3,
    SummaryAmounts2,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    ThresholdType1Code,
    YieldedOrValueType1Choice,
)

__all__ = [
    "ActiveCurrencyAndAmount",
    "ActiveOrHistoricCurrencyAnd13DecimalAmount",
    "Agreement4",
    "AgreementFramework1Choice",
    "AgreementFramework1Code",
    "BlockChainAddressWallet3",
    "BlockChainAddressWallet5",
    "CcpmemberType1Code",
    "CashCollateral4",
    "Collateral53",
    "CollateralAccount3",
    "CollateralAccountIdentificationType3Choice",
    "CollateralAccountType1Code",
    "CollateralAmount1",
    "CollateralAndExposureReportV05",
    "CollateralAppliedExcess1Code",
    "CollateralDirection1Code",
    "CollateralOwnership3",
    "CollateralType8Code",
    "CollateralValuation13",
    "DateAndDateTime2Choice",
    "DateCode9Choice",
    "DateFormat14Choice",
    "DateType2Code",
    "DepositType1Code",
    "Document",
    "EventFrequency6Code",
    "ExposureType11Code",
    "ExposureType13Code",
    "FinancialInstrumentQuantity33Choice",
    "GenericIdentification30",
    "GenericIdentification36",
    "GenericIdentification78",
    "IdentificationSource3Choice",
    "InterestComputationMethod2Code",
    "NameAndAddress6",
    "Obligation11",
    "OtherCollateral10",
    "OtherIdentification1",
    "OtherTypeOfCollateral3",
    "Pagination1",
    "PartyIdentification178Choice",
    "PartyIdentification242",
    "PostalAddress2",
    "Price7",
    "PriceRateOrAmount3Choice",
    "PriceValueType1Code",
    "ReportParameters6",
    "ReturnExcessCash1",
    "ReturnExcessCash1Choice",
    "ReturnExcessCash1Code",
    "SafekeepingPlace1Code",
    "SafekeepingPlace3Code",
    "SafekeepingPlaceFormat29Choice",
    "SafekeepingPlaceTypeAndIdentification1",
    "SafekeepingPlaceTypeAndText8",
    "SecuritiesAccount19",
    "SecuritiesCollateral13",
    "SecurityIdentification19",
    "SettlementStatus3Code",
    "ShortLong1Code",
    "Summary3",
    "SummaryAmounts2",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "ThresholdType1Code",
    "YieldedOrValueType1Choice",
]



from pyiso20022.remt.remt_002_001_01.remt_002_001_01 import (
    AddressType2Code,
    Authorisation1Choice,
    Authorisation1Code,
    BranchAndFinancialInstitutionIdentification5,
    BranchData2,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    ContactDetails2,
    CopyDuplicate1Code,
    DateAndPlaceOfBirth,
    Document,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification8,
    GenericFinancialIdentification1,
    GenericOrganisationIdentification1,
    GenericPersonIdentification1,
    GroupHeader62,
    NameAndAddress10,
    NamePrefix1Code,
    OrganisationIdentification8,
    OrganisationIdentificationSchemeName1Choice,
    Party11Choice,
    PartyIdentification43,
    PersonIdentification5,
    PersonIdentificationSchemeName1Choice,
    PostalAddress6,
    RemittanceLocation3,
    RemittanceLocationAdviceV01,
    RemittanceLocationDetails1,
    RemittanceLocationMethod2Code,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    TransactionReferences4,
)

__all__ = [
    "AddressType2Code",
    "Authorisation1Choice",
    "Authorisation1Code",
    "BranchAndFinancialInstitutionIdentification5",
    "BranchData2",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "ContactDetails2",
    "CopyDuplicate1Code",
    "DateAndPlaceOfBirth",
    "Document",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification8",
    "GenericFinancialIdentification1",
    "GenericOrganisationIdentification1",
    "GenericPersonIdentification1",
    "GroupHeader62",
    "NameAndAddress10",
    "NamePrefix1Code",
    "OrganisationIdentification8",
    "OrganisationIdentificationSchemeName1Choice",
    "Party11Choice",
    "PartyIdentification43",
    "PersonIdentification5",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress6",
    "RemittanceLocation3",
    "RemittanceLocationAdviceV01",
    "RemittanceLocationDetails1",
    "RemittanceLocationMethod2Code",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "TransactionReferences4",
]



from pyiso20022.admi.admi_009_001_02.admi_009_001_02 import (
    Document,
    RequestDetails3,
    StaticDataRequestV02,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "Document",
    "RequestDetails3",
    "StaticDataRequestV02",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from __future__ import annotations

from dataclasses import dataclass, field
from enum import Enum

from xsdata.models.datatype import XmlDate, XmlDateTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03"


class CollateralAccountType1Code(Enum):
    HOUS = "HOUS"
    CLIE = "CLIE"
    LIPR = "LIPR"
    MGIN = "MGIN"
    DFLT = "DFLT"


@dataclass(kw_only=True)
class DateAndDateTimeChoice:
    dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "Dt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )
    dt_tm: None | XmlDateTime = field(
        default=None,
        metadata={
            "name": "DtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )


class ExposureType5Code(Enum):
    BFWD = "BFWD"
    PAYM = "PAYM"
    CCPC = "CCPC"
    COMM = "COMM"
    CRDS = "CRDS"
    CRTL = "CRTL"
    CRSP = "CRSP"
    CCIR = "CCIR"
    CRPR = "CRPR"
    EQUI = "EQUI"
    EQPT = "EQPT"
    EQUS = "EQUS"
    EXTD = "EXTD"
    EXPT = "EXPT"
    FIXI = "FIXI"
    FORX = "FORX"
    FORW = "FORW"
    FUTR = "FUTR"
    OPTN = "OPTN"
    LIQU = "LIQU"
    OTCD = "OTCD"
    REPO = "REPO"
    RVPO = "RVPO"
    SLOA = "SLOA"
    SBSC = "SBSC"
    SCRP = "SCRP"
    SLEB = "SLEB"
    SHSL = "SHSL"
    SCIR = "SCIR"
    SCIE = "SCIE"
    SWPT = "SWPT"
    TBAS = "TBAS"
    TRBD = "TRBD"
    TRCP = "TRCP"


@dataclass(kw_only=True)
class GenericIdentification29:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    issr: str = field(
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class PostalAddress2:
    strt_nm: None | str = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "min_length": 1,
            "max_length": 70,
        },
    )
    pst_cd_id: str = field(
        metadata={
            "name": "PstCdId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 16,
        }
    )
    twn_nm: str = field(
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    ctry_sub_dvsn: None | str = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: str = field(
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        }
    )


@dataclass(kw_only=True)
class Reference16:
    coll_msg_cxl_req_id: str = field(
        metadata={
            "name": "CollMsgCxlReqId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )


class RejectionReasonV021Code(Enum):
    DSEC = "DSEC"
    EVNM = "EVNM"
    UKWN = "UKWN"
    ICOL = "ICOL"
    CONL = "CONL"
    ELIG = "ELIG"
    INID = "INID"
    OTHR = "OTHR"


class Status4Code(Enum):
    REJT = "REJT"
    PACK = "PACK"


@dataclass(kw_only=True)
class SupplementaryDataEnvelope1:
    any_element: None | object = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


@dataclass(kw_only=True)
class CollateralAccountIdentificationType1Choice:
    tp: None | CollateralAccountType1Code = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )
    prtry: None | GenericIdentification29 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )


@dataclass(kw_only=True)
class NameAndAddress6:
    nm: str = field(
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 70,
        }
    )
    adr: PostalAddress2 = field(
        metadata={
            "name": "Adr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class RejectionStatus2:
    rjctd_rsn: RejectionReasonV021Code = field(
        metadata={
            "name": "RjctdRsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )
    addtl_inf: None | str = field(
        default=None,
        metadata={
            "name": "AddtlInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class SupplementaryData1:
    plc_and_nm: None | str = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: SupplementaryDataEnvelope1 = field(
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class CollateralAccount1:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    tp: None | CollateralAccountIdentificationType1Choice = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass(kw_only=True)
class CollateralCancellationStatus1:
    coll_sts_cd: Status4Code = field(
        metadata={
            "name": "CollStsCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )
    addtl_inf: None | str = field(
        default=None,
        metadata={
            "name": "AddtlInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    rjctn_dtls: None | RejectionStatus2 = field(
        default=None,
        metadata={
            "name": "RjctnDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )


@dataclass(kw_only=True)
class PartyIdentification33Choice:
    any_bic: None | str = field(
        default=None,
        metadata={
            "name": "AnyBIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    prtry_id: None | GenericIdentification29 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )
    nm_and_adr: None | NameAndAddress6 = field(
        default=None,
        metadata={
            "name": "NmAndAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )


@dataclass(kw_only=True)
class Obligation3:
    pty_a: PartyIdentification33Choice = field(
        metadata={
            "name": "PtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )
    svcg_pty_a: None | PartyIdentification33Choice = field(
        default=None,
        metadata={
            "name": "SvcgPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )
    pty_b: PartyIdentification33Choice = field(
        metadata={
            "name": "PtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )
    svcg_pty_b: None | PartyIdentification33Choice = field(
        default=None,
        metadata={
            "name": "SvcgPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )
    coll_acct_id: None | CollateralAccount1 = field(
        default=None,
        metadata={
            "name": "CollAcctId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )
    xpsr_tp: None | ExposureType5Code = field(
        default=None,
        metadata={
            "name": "XpsrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )
    valtn_dt: DateAndDateTimeChoice = field(
        metadata={
            "name": "ValtnDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class CollateralManagementCancellationStatusV03:
    tx_id: str = field(
        metadata={
            "name": "TxId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    ref: Reference16 = field(
        metadata={
            "name": "Ref",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )
    oblgtn: Obligation3 = field(
        metadata={
            "name": "Oblgtn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )
    cxl_sts: CollateralCancellationStatus1 = field(
        metadata={
            "name": "CxlSts",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
            "required": True,
        }
    )
    splmtry_data: list[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03",
        },
    )


@dataclass(kw_only=True)
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:colr.006.001.03"

    coll_mgmt_cxl_sts: CollateralManagementCancellationStatusV03 = field(
        metadata={
            "name": "CollMgmtCxlSts",
            "type": "Element",
            "required": True,
        }
    )



from pyiso20022.colr.colr_005_001_04.colr_005_001_04 import (
    CollateralAccount2,
    CollateralAccountIdentificationType2Choice,
    CollateralAccountType1Code,
    CollateralCancellationReason1,
    CollateralCancellationType1Choice,
    CollateralManagementCancellationReason1Code,
    CollateralManagementCancellationRequestV04,
    DateAndDateTimeChoice,
    Document,
    ExposureType5Code,
    GenericIdentification30,
    GenericIdentification36,
    NameAndAddress6,
    Obligation4,
    PartyIdentification100Choice,
    PostalAddress2,
    Reference2Choice,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "CollateralAccount2",
    "CollateralAccountIdentificationType2Choice",
    "CollateralAccountType1Code",
    "CollateralCancellationReason1",
    "CollateralCancellationType1Choice",
    "CollateralManagementCancellationReason1Code",
    "CollateralManagementCancellationRequestV04",
    "DateAndDateTimeChoice",
    "Document",
    "ExposureType5Code",
    "GenericIdentification30",
    "GenericIdentification36",
    "NameAndAddress6",
    "Obligation4",
    "PartyIdentification100Choice",
    "PostalAddress2",
    "Reference2Choice",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from pyiso20022.admi.admi_011_001_01.admi_011_001_01 import (
    Document,
    Event1,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    SystemEventAcknowledgementV01,
)

__all__ = [
    "Document",
    "Event1",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "SystemEventAcknowledgementV01",
]



from pyiso20022.camt.camt_026_001_05.camt_026_001_05 import (
    ActiveOrHistoricCurrencyAndAmount,
    AddressType2Code,
    BranchAndFinancialInstitutionIdentification5,
    BranchData2,
    Case3,
    CaseAssignment3,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    ContactDetails2,
    DateAndDateTimeChoice,
    DateAndPlaceOfBirth,
    Document,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification8,
    GenericFinancialIdentification1,
    GenericOrganisationIdentification1,
    GenericPersonIdentification1,
    MissingOrIncorrectInformation3,
    NamePrefix1Code,
    OrganisationIdentification8,
    OrganisationIdentificationSchemeName1Choice,
    OriginalGroupInformation3,
    Party11Choice,
    Party12Choice,
    PartyIdentification43,
    PersonIdentification5,
    PersonIdentificationSchemeName1Choice,
    PostalAddress6,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    UnableToApplyIncorrect1,
    UnableToApplyIncorrectInformation4Code,
    UnableToApplyJustification3Choice,
    UnableToApplyMissing1,
    UnableToApplyMissingInformation3Code,
    UnableToApplyV05,
    UnderlyingGroupInformation1,
    UnderlyingPaymentInstruction3,
    UnderlyingPaymentTransaction2,
    UnderlyingStatementEntry1,
    UnderlyingTransaction3Choice,
)

__all__ = [
    "ActiveOrHistoricCurrencyAndAmount",
    "AddressType2Code",
    "BranchAndFinancialInstitutionIdentification5",
    "BranchData2",
    "Case3",
    "CaseAssignment3",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "ContactDetails2",
    "DateAndDateTimeChoice",
    "DateAndPlaceOfBirth",
    "Document",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification8",
    "GenericFinancialIdentification1",
    "GenericOrganisationIdentification1",
    "GenericPersonIdentification1",
    "MissingOrIncorrectInformation3",
    "NamePrefix1Code",
    "OrganisationIdentification8",
    "OrganisationIdentificationSchemeName1Choice",
    "OriginalGroupInformation3",
    "Party11Choice",
    "Party12Choice",
    "PartyIdentification43",
    "PersonIdentification5",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress6",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "UnableToApplyIncorrect1",
    "UnableToApplyIncorrectInformation4Code",
    "UnableToApplyJustification3Choice",
    "UnableToApplyMissing1",
    "UnableToApplyMissingInformation3Code",
    "UnableToApplyV05",
    "UnderlyingGroupInformation1",
    "UnderlyingPaymentInstruction3",
    "UnderlyingPaymentTransaction2",
    "UnderlyingStatementEntry1",
    "UnderlyingTransaction3Choice",
]



from pyiso20022.colr.colr_001_001_01.colr_001_001_01 import (
    AccountIdentification4Choice,
    AccountSchemeName1Choice,
    AddressType2Code,
    AddressType3Choice,
    BranchAndFinancialInstitutionIdentification6,
    BranchData3,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    CollateralValueCriteria3,
    CollateralValueCriteriaDefinition3Choice,
    CollateralValueQueryV01,
    CollateralValueReturnCriteria1,
    CollateralValueSearchCriteria3,
    Document,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification18,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification1,
    GenericIdentification30,
    GenericIdentification36,
    IdentificationSource3Choice,
    MessageHeader3,
    NameAndAddress5,
    OriginalBusinessQuery1,
    OtherIdentification1,
    PartyIdentification120Choice,
    PartyIdentification136,
    PostalAddress1,
    PostalAddress24,
    RequestType1Code,
    RequestType2Choice,
    RequestType2Code,
    SecurityIdentification19,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    SystemPartyIdentification8,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountSchemeName1Choice",
    "AddressType2Code",
    "AddressType3Choice",
    "BranchAndFinancialInstitutionIdentification6",
    "BranchData3",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "CollateralValueCriteria3",
    "CollateralValueCriteriaDefinition3Choice",
    "CollateralValueQueryV01",
    "CollateralValueReturnCriteria1",
    "CollateralValueSearchCriteria3",
    "Document",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification18",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification1",
    "GenericIdentification30",
    "GenericIdentification36",
    "IdentificationSource3Choice",
    "MessageHeader3",
    "NameAndAddress5",
    "OriginalBusinessQuery1",
    "OtherIdentification1",
    "PartyIdentification120Choice",
    "PartyIdentification136",
    "PostalAddress1",
    "PostalAddress24",
    "RequestType1Code",
    "RequestType2Choice",
    "RequestType2Code",
    "SecurityIdentification19",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "SystemPartyIdentification8",
]
